local function Dust()
	local ds = {};
	function ds:add(x,y,spd,l,s)
		local ang = math.rad(math.random(360));
		local vx = math.cos(ang)*spd;
		local vy = math.sin(ang)*spd;
		table.insert(self, { x=x, y=y, vx=vx, vy=vy, l=l, s=s } );
	end
	function ds:up(dt)
		for i,k in ipairs(self) do
			if k.l>0 then
				k.x = k.x + k.vx*dt;
				k.y = k.y + k.vy*dt;
				k.l = k.l - math.random(50)*dt;
			else
				table.remove( self, i );
			end
		end
	end
	function ds:draw()
		for i,k in ipairs(self) do
			love.graphics.circle("fill",k.x,k.y,k.s,8);
		end
	end
	return ds;
end
local function Waves( x, y, spd, wlen, whei, width, height)
	local ps = { x = x, y = y };
	ps.time = 0;
	ps.speed = spd/10;
	ps.spd = 2;
	ps.length = wlen/2;
	ps.height = whei;
	ps.sw = width;
	ps.sh = height;
	local size = 40; --SMOOTHNESS
	ps.p = {width/2,height,x,height};
	for i=x, width, size do
		ps.p[#ps.p+1] = i;
		ps.p[#ps.p+1] = y;
	end
	ps.p[#ps.p+1] = width;
	ps.p[#ps.p+1] = y;
	ps.p[#ps.p+1] = width;
	ps.p[#ps.p+1] = height;

	function ps:up( dt )
		self.time = self.time + dt;
		local y,n = 0,5;
		for x = self.x,self.sw, size do
			y = self.y + self.height * math.sin( ( self.time * self.speed - (x/self.length) ) * math.pi );
			self.p[n] = x;
			self.p[n+1] = y;
			n = n + 2;
			if math.random(20)>18 then dust:add(x+math.random(-10,10),y,math.random(5),math.random(5),math.random(3)); end -- Bubbles
		end
		self.p[#self.p-2] = self.y + self.height * math.sin( ( self.time * self.speed - (self.sw/self.length) ) * math.pi );
	end
	function ps:draw( mode )
		love.graphics.polygon(mode,self.p);
	end
	return ps;
end
local color = {
	{114,  5,  5}, {  0, 46,  1},
	{  0, 67, 89}, { 56,  0, 38},
	{ 96, 91,  0}, {  0, 17, 69},
	{ 90, 31,  0}, {  0,  0,  0}
};
function love.load( )
	dust = Dust();
	wave = Waves(0,300,3,2000,130,love.graphics.getWidth(),love.graphics.getHeight()+100);
	c = 6;
	love.graphics.setBackgroundColor(color[c]);
end
function love.update( dt )
	wave:up( dt );
	dust:up( dt );
end
function love.draw( )
	love.graphics.setColor(255,255,255,20);
	dust:draw();
	wave:draw( "fill" );
	love.graphics.setColor(255,255,255,80);
	wave:draw( "line" );
end
function love.keypressed( k )
	if k == "left" then wave.height = math.max( wave.height - 10, 0 );
	elseif k == "right" then wave.height = math.min( wave.height + 10, 240 ); end
	if k == "up" then
		c=c<#color and c+1 or 1;
		love.graphics.setBackgroundColor(color[c]);
	elseif k == "down" then
		c=c>1 and c-1 or #color;
		love.graphics.setBackgroundColor(color[c]);
	end
	if k == "escape" then love.event.quit(); end
end